<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs_CZ">
<context>
    <name>AuthenticationWidget</name>
    <message>
        <location filename="../src/GUI/authenticationwidget.cpp" line="15"/>
        <source>Username:</source>
        <translation>Uživatelské jméno:</translation>
    </message>
    <message>
        <location filename="../src/GUI/authenticationwidget.cpp" line="16"/>
        <source>Password:</source>
        <translation>Heslo:</translation>
    </message>
</context>
<context>
    <name>CadenceGraph</name>
    <message>
        <location filename="../src/GUI/cadencegraph.cpp" line="11"/>
        <source>rpm</source>
        <translation>ot/min</translation>
    </message>
    <message>
        <location filename="../src/GUI/cadencegraph.cpp" line="12"/>
        <location filename="../src/GUI/cadencegraph.h" line="16"/>
        <source>Cadence</source>
        <translation>Kadence</translation>
    </message>
    <message>
        <location filename="../src/GUI/cadencegraph.cpp" line="28"/>
        <source>Avg</source>
        <translation>Průměr</translation>
    </message>
    <message>
        <location filename="../src/GUI/cadencegraph.cpp" line="30"/>
        <source>Max</source>
        <translation>Max</translation>
    </message>
    <message>
        <location filename="../src/GUI/cadencegraph.cpp" line="33"/>
        <source>Average</source>
        <translation>Průměr</translation>
    </message>
    <message>
        <location filename="../src/GUI/cadencegraph.cpp" line="35"/>
        <source>Maximum</source>
        <translation>Maximum</translation>
    </message>
</context>
<context>
    <name>CadenceGraphItem</name>
    <message>
        <location filename="../src/GUI/cadencegraphitem.cpp" line="18"/>
        <source>Maximum</source>
        <translation>Maximum</translation>
    </message>
    <message>
        <location filename="../src/GUI/cadencegraphitem.cpp" line="19"/>
        <location filename="../src/GUI/cadencegraphitem.cpp" line="21"/>
        <source>rpm</source>
        <translation>ot/min</translation>
    </message>
    <message>
        <location filename="../src/GUI/cadencegraphitem.cpp" line="20"/>
        <source>Average</source>
        <translation>Průměr</translation>
    </message>
</context>
<context>
    <name>Data</name>
    <message>
        <location filename="../src/data/data.cpp" line="234"/>
        <source>Supported files</source>
        <translation>Podporované soubory</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="235"/>
        <source>CSV files</source>
        <translation>Soubory CSV</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="236"/>
        <source>CUP files</source>
        <translation>Soubory CUP</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="237"/>
        <source>FIT files</source>
        <translation>Soubory FIT</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="238"/>
        <source>GeoJSON files</source>
        <translation>Soubory GeoJSON</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="239"/>
        <source>GPI files</source>
        <translation>Soubory GPI</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="240"/>
        <source>GPX files</source>
        <translation>Soubory GPX</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="241"/>
        <source>IGC files</source>
        <translation>Soubory IGC</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="242"/>
        <source>ITN files</source>
        <translation>Soubory ITN</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="243"/>
        <source>JPEG images</source>
        <translation>Obrázky JPEG</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="244"/>
        <source>KML files</source>
        <translation>Soubory KML</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="245"/>
        <source>LOC files</source>
        <translation>Soubory LOC</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="246"/>
        <source>NMEA files</source>
        <translation>Soubory NMEA</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="248"/>
        <source>OV2 files</source>
        <translation>Soubory OV2</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="249"/>
        <source>OziExplorer files</source>
        <translation>Soubory OziExploreru</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="251"/>
        <source>SML files</source>
        <translation>Soubory SML</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="252"/>
        <source>TCX files</source>
        <translation>Soubory TCX</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="250"/>
        <source>SLF files</source>
        <translation>Soubory SLF</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="247"/>
        <source>ONmove files</source>
        <translation>Soubory ONmove</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="253"/>
        <source>70mai GPS log files</source>
        <translation>GPS logy z kamer 70mai</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="254"/>
        <source>VKX files</source>
        <translation>Soubory VKX</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="255"/>
        <source>VTK files</source>
        <translation>Soubory VTK</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="256"/>
        <source>TwoNav files</source>
        <translation>Soubory TwoNavu</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="257"/>
        <source>GPSDump files</source>
        <translation>Soubory GPSDumpu</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="258"/>
        <source>All files</source>
        <translation>Všechny soubory</translation>
    </message>
</context>
<context>
    <name>DirSelectWidget</name>
    <message>
        <location filename="../src/GUI/dirselectwidget.cpp" line="18"/>
        <source>System default</source>
        <translation>Výchozí nastavení systému</translation>
    </message>
    <message>
        <location filename="../src/GUI/dirselectwidget.cpp" line="40"/>
        <source>Select directory</source>
        <translation>Vybrat adresář</translation>
    </message>
</context>
<context>
    <name>ElevationGraph</name>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="39"/>
        <location filename="../src/GUI/elevationgraph.h" line="16"/>
        <source>Elevation</source>
        <translation>Výška</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="181"/>
        <source>m</source>
        <translation>m</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="72"/>
        <source>Ascent</source>
        <translation>Stoupání</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="59"/>
        <source>Up</source>
        <extracomment>Use an Unicode arrow (U+2197) when there is no abbreviation or extremly short term for &quot;Up&quot; in your language</extracomment>
        <translation>Nahoru</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="63"/>
        <source>Down</source>
        <extracomment>Use an Unicode arrow (U+2198) when there is no abbreviation or extremly short term for &quot;Down&quot; in your language</extracomment>
        <translation>Dolů</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="66"/>
        <source>Max</source>
        <extracomment>Use an abbreviation or a extremly short term</extracomment>
        <translation>Max</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="69"/>
        <source>Min</source>
        <extracomment>Use an abbreviation or a extremly short term</extracomment>
        <translation>Min</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="74"/>
        <source>Descent</source>
        <translation>Klesání</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="78"/>
        <source>Minimum</source>
        <translation>Minimum</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="184"/>
        <source>ft</source>
        <translation>ft</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="76"/>
        <source>Maximum</source>
        <translation>Maximum</translation>
    </message>
</context>
<context>
    <name>ElevationGraphItem</name>
    <message>
        <location filename="../src/GUI/elevationgraphitem.cpp" line="35"/>
        <source>m</source>
        <translation>m</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraphitem.cpp" line="35"/>
        <source>ft</source>
        <translation>ft</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraphitem.cpp" line="38"/>
        <source>Ascent</source>
        <translation>Stoupání</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraphitem.cpp" line="40"/>
        <source>Descent</source>
        <translation>Klesání</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraphitem.cpp" line="42"/>
        <source>Maximum</source>
        <translation>Maximum</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraphitem.cpp" line="44"/>
        <source>Minimum</source>
        <translation>Minimum</translation>
    </message>
</context>
<context>
    <name>FileSelectWidget</name>
    <message>
        <location filename="../src/GUI/fileselectwidget.cpp" line="46"/>
        <location filename="../src/GUI/fileselectwidget.cpp" line="51"/>
        <source>Select file</source>
        <translation>Vybrat soubor</translation>
    </message>
    <message>
        <location filename="../src/GUI/fileselectwidget.cpp" line="61"/>
        <source>No output file selected.</source>
        <translation>Nebyl zvolen žádný výstupní soubor.</translation>
    </message>
    <message>
        <location filename="../src/GUI/fileselectwidget.cpp" line="71"/>
        <source>%1 is a directory.</source>
        <translation>%1 je adresář.</translation>
    </message>
    <message>
        <location filename="../src/GUI/fileselectwidget.cpp" line="75"/>
        <source>%1 is not writable.</source>
        <translation>%1 nelze zapsat.</translation>
    </message>
</context>
<context>
    <name>Format</name>
    <message>
        <location filename="../src/GUI/format.cpp" line="54"/>
        <location filename="../src/GUI/format.cpp" line="64"/>
        <location filename="../src/GUI/format.cpp" line="93"/>
        <source>ft</source>
        <translation>ft</translation>
    </message>
    <message>
        <location filename="../src/GUI/format.cpp" line="57"/>
        <location filename="../src/GUI/format.cpp" line="60"/>
        <source>mi</source>
        <translation>mi</translation>
    </message>
    <message>
        <location filename="../src/GUI/format.cpp" line="67"/>
        <location filename="../src/GUI/format.cpp" line="70"/>
        <source>nmi</source>
        <translation>nmi</translation>
    </message>
    <message>
        <location filename="../src/GUI/format.cpp" line="74"/>
        <location filename="../src/GUI/format.cpp" line="90"/>
        <source>m</source>
        <translation>m</translation>
    </message>
    <message>
        <location filename="../src/GUI/format.cpp" line="77"/>
        <location filename="../src/GUI/format.cpp" line="80"/>
        <source>km</source>
        <translation>km</translation>
    </message>
</context>
<context>
    <name>GUI</name>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1019"/>
        <location filename="../src/GUI/gui.cpp" line="1022"/>
        <source>Open file</source>
        <translation>Otevřít soubor</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1250"/>
        <location filename="../src/GUI/gui.cpp" line="1253"/>
        <source>Open POI file</source>
        <translation>Otevřít POI soubor</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="200"/>
        <source>Quit</source>
        <translation>Ukončit</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="212"/>
        <location filename="../src/GUI/gui.cpp" line="935"/>
        <location filename="../src/GUI/gui.cpp" line="936"/>
        <source>Keyboard controls</source>
        <translation>Ovládací klávesy</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="254"/>
        <source>Close</source>
        <translation>Zavřít</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="261"/>
        <source>Reload</source>
        <translation>Znovu načíst</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="823"/>
        <source>Show</source>
        <translation>Zobrazit</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="813"/>
        <source>File</source>
        <translation>Soubor</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="303"/>
        <source>Overlap POIs</source>
        <translation>Překrývat POI</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="313"/>
        <source>Show POI labels</source>
        <translation>Zobrazit názvy POI</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="319"/>
        <source>Show POIs</source>
        <translation>Zobrazit POI</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="331"/>
        <source>Show map</source>
        <translation>Zobrazit mapu</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="348"/>
        <source>Clear tile cache</source>
        <translation>Vymazat mezipaměť dlaždic</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="222"/>
        <source>Open...</source>
        <translation>Otevřít...</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="208"/>
        <location filename="../src/GUI/gui.cpp" line="975"/>
        <location filename="../src/GUI/gui.cpp" line="993"/>
        <source>Paths</source>
        <translation>Cesty</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="229"/>
        <source>Open directory...</source>
        <translation>Otevřít adresář...</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="247"/>
        <source>Export to PNG...</source>
        <translation>Exportovat do PNG...</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="267"/>
        <source>Statistics...</source>
        <translation>Statistika...</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="277"/>
        <source>Clear list</source>
        <translation>Smazat seznam</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="289"/>
        <source>Load POI file...</source>
        <translation>Nahrát POI soubor...</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="293"/>
        <source>Select all files</source>
        <translation>Vybrat všechny soubory</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="298"/>
        <source>Unselect all files</source>
        <translation>Odznačit všechny soubory</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="308"/>
        <source>Show POI icons</source>
        <translation>Zobrazit POI ikony</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="340"/>
        <source>Load map...</source>
        <translation>Nahrát mapu...</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="345"/>
        <source>Load map directory...</source>
        <translation>Nahrát adresář s mapami...</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="353"/>
        <location filename="../src/GUI/gui.cpp" line="358"/>
        <location filename="../src/GUI/gui.cpp" line="954"/>
        <source>Next map</source>
        <translation>Následující mapa</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="363"/>
        <source>Show cursor coordinates</source>
        <translation>Zobrazit souřadnice kurzoru</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="371"/>
        <source>All</source>
        <translation>Všechny</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="375"/>
        <source>Raster only</source>
        <translation>Pouze rastrové</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="379"/>
        <source>Vector only</source>
        <translation>Pouze vektorové</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="386"/>
        <source>Show position</source>
        <translation>Zobrazit pozici</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="392"/>
        <source>Follow position</source>
        <translation>Sledovat pozici</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="397"/>
        <source>Show coordinates</source>
        <translation>Zobrazit souřadnice</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="403"/>
        <source>Show motion info</source>
        <translation>Zobrazit informace o pohybu</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="410"/>
        <source>Show tracks</source>
        <translation>Zobrazit cesty</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="415"/>
        <source>Show routes</source>
        <translation>Zobrazit trasy</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="420"/>
        <source>Show waypoints</source>
        <translation>Zobrazit navigační body</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="426"/>
        <source>Show areas</source>
        <translation>Zobrazit plochy</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="431"/>
        <source>Waypoint icons</source>
        <translation>Ikony navigačních bodů</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="436"/>
        <source>Waypoint labels</source>
        <translation>Názvy navigačních bodů</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="446"/>
        <source>km/mi markers</source>
        <translation>Kilometrovníky</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="454"/>
        <source>Do not show</source>
        <translation>Nezobrazovat</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="458"/>
        <source>Marker only</source>
        <translation>Pouze ukazatel</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="462"/>
        <source>Date/time</source>
        <translation>Datum/čas</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="466"/>
        <source>Coordinates</source>
        <translation>Souřadnice</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="470"/>
        <source>Use styles</source>
        <translation>Použít styly</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="488"/>
        <source>Show local DEM tiles</source>
        <translation>Zobrazit lokální DEM dlaždice</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="491"/>
        <source>Show hillshading</source>
        <translation>Stínování kopců</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="499"/>
        <source>Show graphs</source>
        <translation>Zobrazit grafy</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="520"/>
        <source>Show grid</source>
        <translation>Zobrazit mřížku</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="525"/>
        <source>Show slider info</source>
        <translation>Zobrazit informace o posuvníku</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="531"/>
        <source>Show tabs</source>
        <translation>Zobrazit karty</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="540"/>
        <source>Show toolbars</source>
        <translation>Zobrazovat nástrojové lišty</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="547"/>
        <source>Total time</source>
        <translation>Celkový čas</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="552"/>
        <location filename="../src/GUI/gui.cpp" line="1448"/>
        <location filename="../src/GUI/gui.cpp" line="1509"/>
        <source>Moving time</source>
        <translation>Čistý čas</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="559"/>
        <source>Metric</source>
        <translation>Metrické</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="564"/>
        <source>Imperial</source>
        <translation>Imperiální</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="570"/>
        <source>Nautical</source>
        <translation>Námořní</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="578"/>
        <source>Decimal degrees (DD)</source>
        <translation>Desetinné stupně (DD)</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="584"/>
        <source>Degrees and decimal minutes (DMM)</source>
        <translation>Stupně a desetinné minuty (DMM)</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="591"/>
        <source>Degrees, minutes, seconds (DMS)</source>
        <translation>Stupně, minuty, vteřiny (DMS)</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="598"/>
        <source>Fullscreen mode</source>
        <translation>Celoobrazovkový režim</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="605"/>
        <source>Options...</source>
        <translation>Nastavení...</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="612"/>
        <source>Next</source>
        <translation>Následující</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="617"/>
        <source>Previous</source>
        <translation>Předchozí</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="622"/>
        <source>Last</source>
        <translation>Poslední</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="627"/>
        <source>First</source>
        <translation>První</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="665"/>
        <source>Open recent</source>
        <translation>Otevřít nedávný</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="696"/>
        <source>Layers</source>
        <translation>Vrstvy</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="722"/>
        <source>Position info</source>
        <translation>Informace o poloze</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="748"/>
        <source>DEM</source>
        <translation>DEM</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="756"/>
        <source>Position</source>
        <translation>Pozice</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="768"/>
        <source>Units</source>
        <translation>Jednotky</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="773"/>
        <source>Coordinates format</source>
        <translation>Formát souřadnic</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="904"/>
        <location filename="../src/GUI/gui.cpp" line="912"/>
        <source>Version %1</source>
        <translation>Verze %1</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="907"/>
        <location filename="../src/GUI/gui.cpp" line="916"/>
        <source>GPXSee is distributed under the terms of the GNU General Public License version 3. For more info about GPXSee visit the project homepage at %1.</source>
        <translation>Program GPXSee je distribuován pod podmínkami licence GNU General Public License verze 3. Pro více informací navštivte stránky programu na adrese %1.</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="945"/>
        <source>Append file</source>
        <translation>Přidat soubor</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="946"/>
        <source>Next/Previous</source>
        <translation>Následující/Předchozí</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="948"/>
        <source>Toggle graph type</source>
        <translation>Přepnout typ grafu</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="950"/>
        <source>Toggle time type</source>
        <translation>Přepnout typ času</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="952"/>
        <source>Toggle position info</source>
        <translation>Přepnout informace o poloze</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="956"/>
        <source>Previous map</source>
        <translation>Předchozí mapa</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="957"/>
        <source>Zoom in</source>
        <translation>Přiblížit</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="959"/>
        <source>Zoom out</source>
        <translation>Oddálit</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="961"/>
        <source>Digital zoom</source>
        <translation>Digitální zoom</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="962"/>
        <source>Zoom</source>
        <translation>Zoom</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="963"/>
        <source>Copy coordinates</source>
        <translation>Kopírovat souřadnice</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="964"/>
        <source>Left Click</source>
        <translation>Levý klik myši</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="984"/>
        <location filename="../src/GUI/gui.cpp" line="1002"/>
        <source>DEM directory:</source>
        <translation>Adresář s DEM daty:</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="986"/>
        <location filename="../src/GUI/gui.cpp" line="1004"/>
        <source>Styles directory:</source>
        <translation>Adresář se styly:</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="988"/>
        <location filename="../src/GUI/gui.cpp" line="1006"/>
        <source>Symbols directory:</source>
        <translation>Adresář se symboly:</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1054"/>
        <source>Open directory</source>
        <translation>Otevřít adresář</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1126"/>
        <source>Error loading geo URI:</source>
        <translation>geo URI nelze načíst:</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1132"/>
        <location filename="../src/GUI/gui.cpp" line="1172"/>
        <location filename="../src/GUI/gui.cpp" line="1865"/>
        <location filename="../src/GUI/gui.cpp" line="1971"/>
        <source>Don&apos;t show again</source>
        <translation>Již nezobrazovat</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1433"/>
        <location filename="../src/GUI/gui.cpp" line="1491"/>
        <source>Areas</source>
        <translation>Plochy</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1460"/>
        <location filename="../src/GUI/gui.cpp" line="1463"/>
        <location filename="../src/GUI/gui.cpp" line="1464"/>
        <source>Statistics</source>
        <translation>Statistika</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1804"/>
        <location filename="../src/GUI/gui.cpp" line="1807"/>
        <source>Open map file</source>
        <translation>Otevřít mapový soubor</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="2054"/>
        <source>DEM tiles download limit exceeded. If you really need data for such a huge area, download the files manually.</source>
        <translation>Překročen limit pro počet stahovaných DEM dlaždic. Pokud opravdu potřebujete data pro takto velikou oblast, stáhněte dlaždice manuálně.</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="2070"/>
        <source>Could not download all required DEM files.</source>
        <translation>Nepodařilo se stáhnout všechny DEM soubory.</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="2101"/>
        <source>No files loaded</source>
        <translation>Nejsou načteny žádné soubory</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1437"/>
        <location filename="../src/GUI/gui.cpp" line="1439"/>
        <location filename="../src/GUI/gui.cpp" line="1496"/>
        <location filename="../src/GUI/gui.cpp" line="1498"/>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="662"/>
        <source>&amp;File</source>
        <translation>&amp;Soubor</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="690"/>
        <source>&amp;Map</source>
        <translation>&amp;Mapa</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="705"/>
        <source>&amp;Graph</source>
        <translation>&amp;Graf</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="736"/>
        <source>&amp;POI</source>
        <translation>&amp;POI</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="717"/>
        <source>&amp;Data</source>
        <translation>&amp;Data</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="477"/>
        <source>Download data DEM</source>
        <translation>Stáhnout DEM pro data</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="483"/>
        <source>Download map DEM</source>
        <translation>Stáhnout DEM pro mapu</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="763"/>
        <source>&amp;Settings</source>
        <translation>&amp;Nastavení</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="786"/>
        <source>&amp;Help</source>
        <translation>N&amp;ápověda</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="978"/>
        <location filename="../src/GUI/gui.cpp" line="996"/>
        <source>Map directory:</source>
        <translation>Adresář s mapami:</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="980"/>
        <location filename="../src/GUI/gui.cpp" line="998"/>
        <source>POI directory:</source>
        <translation>Adresář s POI body:</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="982"/>
        <location filename="../src/GUI/gui.cpp" line="1000"/>
        <source>CRS directory:</source>
        <translation>Adresář s CRS daty:</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="990"/>
        <location filename="../src/GUI/gui.cpp" line="1008"/>
        <source>Tile cache directory:</source>
        <translation>Adresář mezipaměti dlaždic:</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1429"/>
        <location filename="../src/GUI/gui.cpp" line="1487"/>
        <source>Routes</source>
        <translation>Trasy</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1859"/>
        <location filename="../src/GUI/gui.cpp" line="1922"/>
        <location filename="../src/GUI/gui.cpp" line="1941"/>
        <location filename="../src/GUI/gui.cpp" line="1965"/>
        <source>Error loading map:</source>
        <translation>Mapu nelze načíst:</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="2005"/>
        <source>Select map directory</source>
        <translation>Vybrat adresář s mapami</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="2034"/>
        <source>Clear &quot;%1&quot; tile cache?</source>
        <translation>Vymazat mezipaměť mapy &quot;%1&quot;?</translation>
    </message>
    <message numerus="yes">
        <location filename="../src/GUI/gui.cpp" line="2057"/>
        <source>Download %n DEM tiles?</source>
        <translation>
            <numerusform>Stáhnout %n DEM dlaždici?</numerusform>
            <numerusform>Stáhnout %n DEM dlaždice?</numerusform>
            <numerusform>Stáhnout %n DEM dlaždic?</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="2087"/>
        <source>No local DEM tiles found.</source>
        <translation>Nebyly nalezeny žádné lokální DEM dlaždice.</translation>
    </message>
    <message numerus="yes">
        <location filename="../src/GUI/gui.cpp" line="2105"/>
        <source>%n files</source>
        <translation>
            <numerusform>%n soubor</numerusform>
            <numerusform>%n soubory</numerusform>
            <numerusform>%n souborů</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="939"/>
        <source>Next file</source>
        <translation>Následující soubor</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="234"/>
        <source>Print...</source>
        <translation>Tisknout...</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="240"/>
        <source>Export to PDF...</source>
        <translation>Exportovat do PDF...</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1431"/>
        <location filename="../src/GUI/gui.cpp" line="1489"/>
        <source>Waypoints</source>
        <translation>Navigační body</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="940"/>
        <source>Previous file</source>
        <translation>Předchozí soubor</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="441"/>
        <source>Route waypoints</source>
        <translation>Body tras</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="942"/>
        <source>First file</source>
        <translation>První soubor</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="944"/>
        <source>Last file</source>
        <translation>Poslední soubor</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1164"/>
        <source>Error loading data file:</source>
        <translation>Datový soubor nelze načíst:</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1167"/>
        <location filename="../src/GUI/gui.cpp" line="1283"/>
        <source>Line: %1</source>
        <translation>Řádka: %1</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1280"/>
        <source>Error loading POI file:</source>
        <translation>Soubor POI nelze načíst:</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1481"/>
        <source>Name</source>
        <translation>Název</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1427"/>
        <location filename="../src/GUI/gui.cpp" line="1485"/>
        <source>Tracks</source>
        <translation>Cesty</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="216"/>
        <location filename="../src/GUI/gui.cpp" line="902"/>
        <source>About GPXSee</source>
        <translation>O aplikaci GPXSee</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="831"/>
        <source>Navigation</source>
        <translation>Navigace</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="507"/>
        <location filename="../src/GUI/gui.cpp" line="1445"/>
        <location filename="../src/GUI/gui.cpp" line="1505"/>
        <source>Distance</source>
        <translation>Vzdálenost</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="514"/>
        <location filename="../src/GUI/gui.cpp" line="764"/>
        <location filename="../src/GUI/gui.cpp" line="1447"/>
        <location filename="../src/GUI/gui.cpp" line="1507"/>
        <source>Time</source>
        <translation>Čas</translation>
    </message>
</context>
<context>
    <name>GearRatioGraph</name>
    <message>
        <location filename="../src/GUI/gearratiograph.cpp" line="12"/>
        <location filename="../src/GUI/gearratiograph.h" line="17"/>
        <source>Gear ratio</source>
        <translation>Převodový poměr</translation>
    </message>
    <message>
        <location filename="../src/GUI/gearratiograph.cpp" line="28"/>
        <source>Top</source>
        <translation>Nej</translation>
    </message>
    <message>
        <location filename="../src/GUI/gearratiograph.cpp" line="30"/>
        <source>Min</source>
        <translation>Min</translation>
    </message>
    <message>
        <location filename="../src/GUI/gearratiograph.cpp" line="32"/>
        <source>Max</source>
        <translation>Max</translation>
    </message>
    <message>
        <location filename="../src/GUI/gearratiograph.cpp" line="35"/>
        <source>Most used</source>
        <translation>Nejpoužívanější</translation>
    </message>
    <message>
        <location filename="../src/GUI/gearratiograph.cpp" line="37"/>
        <source>Minimum</source>
        <translation>Minimum</translation>
    </message>
    <message>
        <location filename="../src/GUI/gearratiograph.cpp" line="39"/>
        <source>Maximum</source>
        <translation>Maximum</translation>
    </message>
</context>
<context>
    <name>GearRatioGraphItem</name>
    <message>
        <location filename="../src/GUI/gearratiographitem.cpp" line="37"/>
        <source>Minimum</source>
        <translation>Minimum</translation>
    </message>
    <message>
        <location filename="../src/GUI/gearratiographitem.cpp" line="38"/>
        <source>Maximum</source>
        <translation>Maximum</translation>
    </message>
    <message>
        <location filename="../src/GUI/gearratiographitem.cpp" line="39"/>
        <source>Most used</source>
        <translation>Nejpoužívanější</translation>
    </message>
</context>
<context>
    <name>GraphView</name>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="139"/>
        <source>m</source>
        <translation>m</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="142"/>
        <source>km</source>
        <translation>km</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="123"/>
        <location filename="../src/GUI/graphview.cpp" line="131"/>
        <source>ft</source>
        <translation>ft</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="67"/>
        <source>Data not available</source>
        <translation>Data nejsou k dispozici</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="126"/>
        <source>mi</source>
        <translation>mi</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="134"/>
        <source>nmi</source>
        <translation>nmi</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="148"/>
        <source>s</source>
        <translation>s</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="151"/>
        <source>min</source>
        <translation>min</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="154"/>
        <source>h</source>
        <translation>h</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="86"/>
        <location filename="../src/GUI/graphview.cpp" line="191"/>
        <source>Distance</source>
        <translation>Vzdálenost</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="193"/>
        <source>Time</source>
        <translation>Čas</translation>
    </message>
</context>
<context>
    <name>HeartRateGraph</name>
    <message>
        <location filename="../src/GUI/heartrategraph.cpp" line="12"/>
        <location filename="../src/GUI/heartrategraph.h" line="16"/>
        <source>Heart rate</source>
        <translation>Tep</translation>
    </message>
    <message>
        <location filename="../src/GUI/heartrategraph.cpp" line="11"/>
        <source>bpm</source>
        <translation>tepů/min</translation>
    </message>
    <message>
        <location filename="../src/GUI/heartrategraph.cpp" line="28"/>
        <source>Avg</source>
        <translation>Průměr</translation>
    </message>
    <message>
        <location filename="../src/GUI/heartrategraph.cpp" line="30"/>
        <source>Max</source>
        <translation>Max</translation>
    </message>
    <message>
        <location filename="../src/GUI/heartrategraph.cpp" line="33"/>
        <source>Average</source>
        <translation>Průměr</translation>
    </message>
    <message>
        <location filename="../src/GUI/heartrategraph.cpp" line="35"/>
        <source>Maximum</source>
        <translation>Maximum</translation>
    </message>
</context>
<context>
    <name>HeartRateGraphItem</name>
    <message>
        <location filename="../src/GUI/heartrategraphitem.cpp" line="19"/>
        <source>Maximum</source>
        <translation>Maximum</translation>
    </message>
    <message>
        <location filename="../src/GUI/heartrategraphitem.cpp" line="20"/>
        <location filename="../src/GUI/heartrategraphitem.cpp" line="22"/>
        <source>bpm</source>
        <translation>tepů/min</translation>
    </message>
    <message>
        <location filename="../src/GUI/heartrategraphitem.cpp" line="21"/>
        <source>Average</source>
        <translation>Průměr</translation>
    </message>
</context>
<context>
    <name>MapItem</name>
    <message>
        <location filename="../src/GUI/mapitem.cpp" line="80"/>
        <source>Name</source>
        <translation>Název</translation>
    </message>
    <message>
        <location filename="../src/GUI/mapitem.cpp" line="82"/>
        <source>File</source>
        <translation>Soubor</translation>
    </message>
</context>
<context>
    <name>MapList</name>
    <message>
        <location filename="../src/map/maplist.cpp" line="158"/>
        <source>Supported files</source>
        <translation>Podporované soubory</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="171"/>
        <source>MBTiles maps</source>
        <translation>MBTiles mapy</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="166"/>
        <source>Garmin JNX maps</source>
        <translation>Garmin JNX mapy</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="162"/>
        <source>AlpineQuest maps</source>
        <translation>AlpineQuest mapy</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="164"/>
        <source>Garmin IMG maps</source>
        <translation>Garmin IMG mapy</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="167"/>
        <source>BSB nautical charts</source>
        <translation>BSB námořní mapy</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="163"/>
        <source>GEMF maps</source>
        <translation>GEMF mapy</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="160"/>
        <source>Electronic Navigational Charts</source>
        <translation>ENC námořní mapy</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="168"/>
        <source>KMZ maps</source>
        <translation>KMZ mapy</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="169"/>
        <source>Mapsforge maps</source>
        <translation>Mapsforge mapy</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="170"/>
        <source>OziExplorer maps</source>
        <translation>OziExplorer mapy</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="172"/>
        <source>Orux maps</source>
        <translation>Orux mapy</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="173"/>
        <source>QuickChart maps</source>
        <translation>QuickChart mapy</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="175"/>
        <source>Osmdroid SQLite maps</source>
        <translation>Osmdroid SQLite mapy</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="178"/>
        <source>TrekBuddy maps/atlases</source>
        <translation>TrekBuddy mapy/atlasy</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="180"/>
        <source>GeoTIFF images</source>
        <translation>GeoTIFF obrázky</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="184"/>
        <source>All files</source>
        <translation>Všechny soubory</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="174"/>
        <source>TwoNav maps</source>
        <translation>TwoNav mapy</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="176"/>
        <source>Locus/OsmAnd/RMaps SQLite maps</source>
        <translation>Locus/OsmAnd/RMaps SQLite mapy</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="181"/>
        <source>World-file georeferenced images</source>
        <translation>Georeferencované obrázky - world-file</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="183"/>
        <source>Online map sources</source>
        <translation>Online mapové zdroje</translation>
    </message>
</context>
<context>
    <name>MotionInfoItem</name>
    <message>
        <location filename="../src/GUI/motioninfoitem.cpp" line="87"/>
        <source>kn</source>
        <translation>kn</translation>
    </message>
    <message>
        <location filename="../src/GUI/motioninfoitem.cpp" line="90"/>
        <source>mi/h</source>
        <translation>mi/h</translation>
    </message>
    <message>
        <location filename="../src/GUI/motioninfoitem.cpp" line="93"/>
        <source>km/h</source>
        <translation>km/h</translation>
    </message>
    <message>
        <location filename="../src/GUI/motioninfoitem.cpp" line="100"/>
        <source>ft/min</source>
        <translation>ft/min</translation>
    </message>
    <message>
        <location filename="../src/GUI/motioninfoitem.cpp" line="103"/>
        <source>m/min</source>
        <translation>m/min</translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="187"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="210"/>
        <source>Base color:</source>
        <translation>Základní barva:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="188"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="211"/>
        <source>Palette shift:</source>
        <translation>Posun palety:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="177"/>
        <source>Track width:</source>
        <translation>Šířka cest:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="178"/>
        <source>Track style:</source>
        <translation>Styl cest:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="196"/>
        <source>Tracks</source>
        <translation>Cesty</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="180"/>
        <source>Route width:</source>
        <translation>Šířka tras:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="181"/>
        <source>Route style:</source>
        <translation>Styl tras:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="201"/>
        <source>Routes</source>
        <translation>Trasy</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="171"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="275"/>
        <source>Use anti-aliasing</source>
        <translation>Vyhlazovat hrany</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="281"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="287"/>
        <source>Line width:</source>
        <translation>Šířka čar:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="313"/>
        <source>Background color:</source>
        <translation>Barva pozadí:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="326"/>
        <source>Paths</source>
        <translation>Trasy</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="329"/>
        <source>Map</source>
        <translation>Mapa</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="328"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="764"/>
        <source>Graphs</source>
        <translation>Grafy</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="78"/>
        <source>Select the proper coordinate reference system (CRS) of maps without a CRS definition (JNX, KMZ and World file maps).</source>
        <translation>Souřadnicový referenční systém (CRS) map u kterých není CRS uveden (JNX, KMZ a World-file soubory).</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="81"/>
        <source>Select the desired projection of vector maps (IMG, Mapsforge and ENC maps). The projection must be valid for the whole map area.</source>
        <translation>Projekce vektorových map (IMG, Mapsforge a ENC). Projekce musí být platná přes celou oblast mapy.</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="86"/>
        <source>Standard</source>
        <translation>Standardní</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="91"/>
        <source>Non-HiDPI maps are loaded as HiDPI maps. The map is sharp but map objects are small/hard to read.</source>
        <translation>Ne-HiDPI mapy jsou načteny jako HiDPI mapy. Mapa je ostrá, ale objekty na mapě jsou malé/těžko čitelné.</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="93"/>
        <source>Non-HiDPI maps are loaded such as they are. Map objects have the expected size but the map is blurry.</source>
        <translation>Ne-HiDPI mapy jsou načteny tak jak jsou. Objekty na mapě mají očekávanou velikost, ale mapa je rozmazaná.</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="103"/>
        <source>Input</source>
        <translation>Vstup</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="105"/>
        <source>Output</source>
        <translation>Výstup</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="112"/>
        <source>Input:</source>
        <translation>Vstup:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="115"/>
        <source>Output:</source>
        <translation>Výstup:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="136"/>
        <source>Projection</source>
        <translation>Projekce</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="137"/>
        <source>HiDPI display mode</source>
        <translation>HiDPI režim zobrazení</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="194"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="199"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="204"/>
        <source>Width:</source>
        <translation>Šířka:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="195"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="200"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="205"/>
        <source>Style:</source>
        <translation>Styl:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="243"/>
        <source>Waypoint color:</source>
        <translation>Barva navigačních bodů:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="244"/>
        <source>Waypoint size:</source>
        <translation>Velikost navigačních bodů:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="251"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="256"/>
        <source>Color:</source>
        <translation>Barva:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="252"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="257"/>
        <source>Size:</source>
        <translation>Velikost:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="253"/>
        <source>Waypoints</source>
        <translation>Navigační body</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="246"/>
        <source>POI color:</source>
        <translation>Barva POI:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="247"/>
        <source>POI size:</source>
        <translation>Velikost POI:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="258"/>
        <source>POIs</source>
        <translation>POI body</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="282"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="288"/>
        <source>Slider color:</source>
        <translation>Barva posuvníku:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="327"/>
        <source>Points</source>
        <translation>Body</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="336"/>
        <source>Moving average window size</source>
        <translation>Velikost okna klouzavého průměru</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="361"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="371"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="495"/>
        <source>Elevation:</source>
        <translation>Výška:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="362"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="372"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="494"/>
        <source>Speed:</source>
        <translation>Rychlost:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="363"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="373"/>
        <source>Heart rate:</source>
        <translation>Tep:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="364"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="374"/>
        <source>Cadence:</source>
        <translation>Kadence:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="365"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="375"/>
        <source>Power:</source>
        <translation>Výkon:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="360"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="378"/>
        <source>Smoothing</source>
        <translation>Vyhlazování</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="354"/>
        <source>Eliminate GPS outliers</source>
        <translation>Odstarnit odlehlé GPS záznamy</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="391"/>
        <source>Automatic</source>
        <translation>Automatická</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="405"/>
        <source>mi/h</source>
        <translation>mi/h</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="408"/>
        <source>kn</source>
        <translation>kn</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="411"/>
        <source>km/h</source>
        <translation>km/h</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="415"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="791"/>
        <source>s</source>
        <translation>s</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="538"/>
        <source>Minimal speed:</source>
        <translation>Minimální rychlost:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="539"/>
        <source>Minimal duration:</source>
        <translation>Minimální trvání:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="426"/>
        <source>Computed from distance/time</source>
        <translation>Vypočítaná ze vzdálenosti/času</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="427"/>
        <source>Recorded by device</source>
        <translation>Zaznamenaná zařízením</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="432"/>
        <source>Show secondary speed</source>
        <translation>Zobrazit sekundární rychlost</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="435"/>
        <source>GPS data</source>
        <translation>GPS data</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="436"/>
        <source>DEM data</source>
        <translation>DEM data</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="441"/>
        <source>Show secondary elevation</source>
        <translation>Zobrazit sekundární výšku</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="444"/>
        <source>UTC</source>
        <translation>UTC</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="465"/>
        <source>Use segments</source>
        <translation>Použít segmenty</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="496"/>
        <source>Time zone:</source>
        <translation>Časová zóna:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="515"/>
        <source>Elevation</source>
        <translation>Výška</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="521"/>
        <source>Time zone</source>
        <translation>Časová zóna</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="551"/>
        <source>Filtering</source>
        <translation>Filtrování</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="550"/>
        <source>Sources</source>
        <translation>Zdroje</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="552"/>
        <source>Pause detection</source>
        <translation>Detekce přestávek</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="574"/>
        <source>Radius:</source>
        <translation>Radius:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="510"/>
        <source>Speed</source>
        <translation>Rychlost</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="147"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="154"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="160"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="228"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="235"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="273"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="639"/>
        <source>px</source>
        <translation>px</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="183"/>
        <source>Area border width:</source>
        <translation>Šířka okrajů ploch:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="184"/>
        <source>Area border style:</source>
        <translation>Styl okrajů ploch:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="185"/>
        <source>Area fill opacity:</source>
        <translation>Neprůhlednost výplně ploch:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="207"/>
        <source>Areas</source>
        <translation>Plochy</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="309"/>
        <source>Info background</source>
        <translation>Pozadí textu</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="315"/>
        <source>Crosshair color:</source>
        <translation>Barva zaměřovače:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="316"/>
        <source>Info color:</source>
        <translation>Barva textu:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="392"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="446"/>
        <source>Custom</source>
        <translation>Vlastní</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="564"/>
        <source>mi</source>
        <translation>mi</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="567"/>
        <source>nmi</source>
        <translation>nmi</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="570"/>
        <source>km</source>
        <translation>km</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="580"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="884"/>
        <source>POI</source>
        <translation>POI</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="597"/>
        <source>Use HTTP authentication</source>
        <translation>Použít HTTP autentizaci</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="603"/>
        <source>Use $lat and $lon for NYY/SYY and EXXX/WXXX in the URL.</source>
        <translation>NYY/SYY a EXXX/WXXX v URL nahraďte za $lat a $lon.</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="608"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="621"/>
        <source>URL:</source>
        <translation>URL:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="206"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="314"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="655"/>
        <source>Opacity:</source>
        <translation>Neprůhlednost:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="657"/>
        <source>Blur radius:</source>
        <translation>Poloměr rozostření:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="659"/>
        <source>Azimuth:</source>
        <translation>Azimut:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="660"/>
        <source>Altitude:</source>
        <translation>Výška:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="661"/>
        <source>Z Factor:</source>
        <translation>Z-faktor:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="666"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="696"/>
        <source>Source</source>
        <translation>Zdroj dat</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="667"/>
        <source>Hillshading</source>
        <translation>Stínování kopců</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="685"/>
        <source>Plugin:</source>
        <translation>Plugin:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="703"/>
        <source>WYSIWYG</source>
        <translation>WYSIWYG</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="85"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="704"/>
        <source>High-Resolution</source>
        <translation>Vysoké rozlišení</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="388"/>
        <source>Detect pauses</source>
        <translation>Detekovat přestávky</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="537"/>
        <source>Detection:</source>
        <translation>Detekce:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="656"/>
        <source>Lightening:</source>
        <translation>Zesvětlení:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="709"/>
        <source>The printed area is approximately the display area. The map zoom level does not change.</source>
        <translation>Oblast tisku přibližně odpovídá zobrazované oblasti. Přiblížení mapy se nemění.</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="711"/>
        <source>The zoom level will be changed so that the whole content (tracks/waypoints) fits to the printed area and the map resolution is as close as possible to the print resolution.</source>
        <translation>Přiblížení mapy bude upraveno tak, aby se celý obsah (trasy/body) vešel do oblasti tisku a rozlišení mapy bylo co nejblíže rozlišení tisku.</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="727"/>
        <source>Name</source>
        <translation>Název</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="729"/>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="731"/>
        <source>Distance</source>
        <translation>Vzdálenost</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="733"/>
        <source>Time</source>
        <translation>Čas</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="735"/>
        <source>Moving time</source>
        <translation>Čistý čas</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="737"/>
        <source>Item count (&gt;1)</source>
        <translation>Počet objektů (&gt;1)</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="752"/>
        <source>Separate graph page</source>
        <translation>Samostatná stránka s grafy</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="762"/>
        <source>Print mode</source>
        <translation>Režim tisku</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="763"/>
        <source>Header</source>
        <translation>Záhlaví</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="771"/>
        <source>Use OpenGL</source>
        <translation>Používat OpenGL</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="773"/>
        <source>Enable HTTP/2</source>
        <translation>Povolit HTTP/2</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="779"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="785"/>
        <source>MB</source>
        <translation>MB</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="797"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="805"/>
        <source>Image cache size:</source>
        <translation>Mezipaměť obrázků:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="799"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="807"/>
        <source>Connection timeout:</source>
        <translation>Časový limit připojení:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="445"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="842"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="893"/>
        <source>System</source>
        <translation>Systém</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="798"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="806"/>
        <source>DEM cache size:</source>
        <translation>Mezipaměť DEM:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="826"/>
        <source>Select the initial paths of the file open dialogues. Leave the field empty for the system default.</source>
        <translation>Výchozí cesty v dialozích pro výběr souborů. Nevyplňené pole odpovídá výchozímu nastavení systému.</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="830"/>
        <source>Data:</source>
        <translation>Data:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="831"/>
        <source>Maps:</source>
        <translation>Mapy:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="832"/>
        <source>POI:</source>
        <translation>POI:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="843"/>
        <source>Initial paths</source>
        <translation>Výchozí cesty</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="879"/>
        <source>Appearance</source>
        <translation>Vzhled</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="881"/>
        <source>Maps</source>
        <translation>Mapy</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="883"/>
        <source>Data</source>
        <translation>Data</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="886"/>
        <source>DEM</source>
        <translation>DEM</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="889"/>
        <source>Position</source>
        <translation>Pozice</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="891"/>
        <source>Print &amp; Export</source>
        <translation>Tisk a export</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="926"/>
        <source>Options</source>
        <translation>Nastavení</translation>
    </message>
</context>
<context>
    <name>PDFExportDialog</name>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="28"/>
        <source>PDF files</source>
        <translation>Soubory PDF</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="28"/>
        <source>All files</source>
        <translation>Všechny soubory</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="56"/>
        <source>Portrait</source>
        <translation>Na výšku</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="57"/>
        <source>Landscape</source>
        <translation>Na šířku</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="67"/>
        <source>in</source>
        <translation>in</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="67"/>
        <source>cm</source>
        <translation>cm</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="73"/>
        <source>Page Setup</source>
        <translation>Nastavení stránky</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="76"/>
        <source>Page size:</source>
        <translation>Velikost stránky:</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="77"/>
        <source>Resolution:</source>
        <translation>Rozlišení:</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="78"/>
        <source>Orientation:</source>
        <translation>Orientace:</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="79"/>
        <source>Margins:</source>
        <translation>Okraje:</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="85"/>
        <source>File:</source>
        <translation>Soubor:</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="92"/>
        <source>Output file</source>
        <translation>Výstupní soubor</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="99"/>
        <source>Export</source>
        <translation>Exportovat</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="119"/>
        <source>Export to PDF</source>
        <translation>Exportovat do PDF</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="127"/>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
</context>
<context>
    <name>PNGExportDialog</name>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="25"/>
        <source>PNG files</source>
        <translation>Soubory PNG</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="25"/>
        <source>All files</source>
        <translation>Všechny soubory</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="34"/>
        <location filename="../src/GUI/pngexportdialog.cpp" line="39"/>
        <location filename="../src/GUI/pngexportdialog.cpp" line="43"/>
        <source>px</source>
        <translation>px</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="45"/>
        <source>Use anti-aliasing</source>
        <translation>Vyhlazovat hrany</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="49"/>
        <source>Image Setup</source>
        <translation>Nastavení obrázku</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="52"/>
        <source>Image width:</source>
        <translation>Šířka:</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="53"/>
        <source>Image height:</source>
        <translation>Výška:</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="54"/>
        <source>Margins:</source>
        <translation>Okraje:</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="61"/>
        <source>File:</source>
        <translation>Soubor:</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="68"/>
        <source>Output file</source>
        <translation>Výstupní soubor</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="75"/>
        <source>Export</source>
        <translation>Exportovat</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="95"/>
        <source>Export to PNG</source>
        <translation>Exportovat do PNG</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="103"/>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
</context>
<context>
    <name>PolygonItem</name>
    <message>
        <location filename="../src/GUI/areaitem.cpp" line="18"/>
        <source>Name</source>
        <translation>Název</translation>
    </message>
    <message>
        <location filename="../src/GUI/areaitem.cpp" line="20"/>
        <source>Description</source>
        <translation>Popis</translation>
    </message>
</context>
<context>
    <name>PowerGraph</name>
    <message>
        <location filename="../src/GUI/powergraph.cpp" line="11"/>
        <source>W</source>
        <translation>W</translation>
    </message>
    <message>
        <location filename="../src/GUI/powergraph.cpp" line="12"/>
        <location filename="../src/GUI/powergraph.h" line="16"/>
        <source>Power</source>
        <translation>Výkon</translation>
    </message>
    <message>
        <location filename="../src/GUI/powergraph.cpp" line="28"/>
        <source>Avg</source>
        <translation>Průměr</translation>
    </message>
    <message>
        <location filename="../src/GUI/powergraph.cpp" line="30"/>
        <source>Max</source>
        <translation>Max</translation>
    </message>
    <message>
        <location filename="../src/GUI/powergraph.cpp" line="33"/>
        <source>Average</source>
        <translation>Průměr</translation>
    </message>
    <message>
        <location filename="../src/GUI/powergraph.cpp" line="35"/>
        <source>Maximum</source>
        <translation>Maximum</translation>
    </message>
</context>
<context>
    <name>PowerGraphItem</name>
    <message>
        <location filename="../src/GUI/powergraphitem.cpp" line="18"/>
        <source>Maximum</source>
        <translation>Maximum</translation>
    </message>
    <message>
        <location filename="../src/GUI/powergraphitem.cpp" line="19"/>
        <location filename="../src/GUI/powergraphitem.cpp" line="21"/>
        <source>W</source>
        <translation>W</translation>
    </message>
    <message>
        <location filename="../src/GUI/powergraphitem.cpp" line="20"/>
        <source>Average</source>
        <translation>Průměr</translation>
    </message>
</context>
<context>
    <name>RouteItem</name>
    <message>
        <location filename="../src/GUI/routeitem.cpp" line="16"/>
        <source>Name</source>
        <translation>Název</translation>
    </message>
    <message>
        <location filename="../src/GUI/routeitem.cpp" line="18"/>
        <source>Description</source>
        <translation>Popis</translation>
    </message>
    <message>
        <location filename="../src/GUI/routeitem.cpp" line="20"/>
        <source>Comment</source>
        <translation>Poznámka</translation>
    </message>
    <message>
        <location filename="../src/GUI/routeitem.cpp" line="21"/>
        <source>Distance</source>
        <translation>Vzdálenost</translation>
    </message>
    <message>
        <location filename="../src/GUI/routeitem.cpp" line="32"/>
        <source>Links</source>
        <translation>Odkazy</translation>
    </message>
    <message>
        <location filename="../src/GUI/routeitem.cpp" line="38"/>
        <source>File</source>
        <translation>Soubor</translation>
    </message>
</context>
<context>
    <name>ScaleItem</name>
    <message>
        <location filename="../src/GUI/scaleitem.cpp" line="108"/>
        <source>mi</source>
        <translation>mi</translation>
    </message>
    <message>
        <location filename="../src/GUI/scaleitem.cpp" line="109"/>
        <location filename="../src/GUI/scaleitem.cpp" line="112"/>
        <source>ft</source>
        <translation>ft</translation>
    </message>
    <message>
        <location filename="../src/GUI/scaleitem.cpp" line="111"/>
        <source>nmi</source>
        <translation>nmi</translation>
    </message>
    <message>
        <location filename="../src/GUI/scaleitem.cpp" line="114"/>
        <source>km</source>
        <translation>km</translation>
    </message>
    <message>
        <location filename="../src/GUI/scaleitem.cpp" line="115"/>
        <source>m</source>
        <translation>m</translation>
    </message>
</context>
<context>
    <name>SpeedGraph</name>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="15"/>
        <location filename="../src/GUI/speedgraph.h" line="18"/>
        <source>Speed</source>
        <translation>Rychlost</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="152"/>
        <source>km/h</source>
        <translation>km/h</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="39"/>
        <source>Average</source>
        <translation>Průměr</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="30"/>
        <source>min/km</source>
        <translation>min/km</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="31"/>
        <source>min/mi</source>
        <translation>min/mi</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="31"/>
        <source>min/nmi</source>
        <translation>min/nmi</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="34"/>
        <source>Avg</source>
        <translation>Průměr</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="36"/>
        <source>Max</source>
        <translation>Max</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="41"/>
        <source>Maximum</source>
        <translation>Maximum</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="44"/>
        <source>Pace</source>
        <translation>Tempo</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="146"/>
        <source>kn</source>
        <translation>kn</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="149"/>
        <source>mi/h</source>
        <translation>mi/h</translation>
    </message>
</context>
<context>
    <name>SpeedGraphItem</name>
    <message>
        <location filename="../src/GUI/speedgraphitem.cpp" line="26"/>
        <source>km/h</source>
        <translation>km/h</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraphitem.cpp" line="25"/>
        <source>mi/h</source>
        <translation>mi/h</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraphitem.cpp" line="26"/>
        <source>kn</source>
        <translation>kn</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraphitem.cpp" line="29"/>
        <source>min/km</source>
        <translation>min/km</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraphitem.cpp" line="30"/>
        <source>min/mi</source>
        <translation>min/mi</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraphitem.cpp" line="30"/>
        <source>min/nmi</source>
        <translation>min/nmi</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraphitem.cpp" line="33"/>
        <source>Maximum</source>
        <translation>Maximum</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraphitem.cpp" line="35"/>
        <source>Average</source>
        <translation>Průměr</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraphitem.cpp" line="37"/>
        <source>Pace</source>
        <translation>Tempo</translation>
    </message>
</context>
<context>
    <name>TemperatureGraph</name>
    <message>
        <location filename="../src/GUI/temperaturegraph.cpp" line="12"/>
        <location filename="../src/GUI/temperaturegraph.h" line="16"/>
        <source>Temperature</source>
        <translation>Teplota</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraph.cpp" line="28"/>
        <source>Avg</source>
        <translation>Průměr</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraph.cpp" line="30"/>
        <source>Min</source>
        <translation>Min</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraph.cpp" line="32"/>
        <source>Max</source>
        <translation>Max</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraph.cpp" line="35"/>
        <source>Average</source>
        <translation>Průměr</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraph.cpp" line="37"/>
        <source>Minimum</source>
        <translation>Minimum</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraph.cpp" line="39"/>
        <source>Maximum</source>
        <translation>Maximum</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraph.cpp" line="112"/>
        <source>C</source>
        <translation>C</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraph.cpp" line="116"/>
        <source>F</source>
        <translation>F</translation>
    </message>
</context>
<context>
    <name>TemperatureGraphItem</name>
    <message>
        <location filename="../src/GUI/temperaturegraphitem.cpp" line="23"/>
        <source>C</source>
        <translation>C</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraphitem.cpp" line="23"/>
        <source>F</source>
        <translation>F</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraphitem.cpp" line="26"/>
        <source>Average</source>
        <translation>Průměr</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraphitem.cpp" line="28"/>
        <source>Maximum</source>
        <translation>Maximum</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraphitem.cpp" line="30"/>
        <source>Minimum</source>
        <translation>Minimum</translation>
    </message>
</context>
<context>
    <name>TrackItem</name>
    <message>
        <location filename="../src/GUI/trackitem.cpp" line="15"/>
        <source>Name</source>
        <translation>Název</translation>
    </message>
    <message>
        <location filename="../src/GUI/trackitem.cpp" line="17"/>
        <source>Description</source>
        <translation>Popis</translation>
    </message>
    <message>
        <location filename="../src/GUI/trackitem.cpp" line="19"/>
        <source>Comment</source>
        <translation>Poznámka</translation>
    </message>
    <message>
        <location filename="../src/GUI/trackitem.cpp" line="20"/>
        <source>Distance</source>
        <translation>Vzdálenost</translation>
    </message>
    <message>
        <location filename="../src/GUI/trackitem.cpp" line="23"/>
        <source>Total time</source>
        <translation>Celkový čas</translation>
    </message>
    <message>
        <location filename="../src/GUI/trackitem.cpp" line="25"/>
        <source>Moving time</source>
        <translation>Čistý čas</translation>
    </message>
    <message>
        <location filename="../src/GUI/trackitem.cpp" line="28"/>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <location filename="../src/GUI/trackitem.cpp" line="40"/>
        <source>Links</source>
        <translation>Odkazy</translation>
    </message>
    <message>
        <location filename="../src/GUI/trackitem.cpp" line="46"/>
        <source>File</source>
        <translation>Soubor</translation>
    </message>
</context>
<context>
    <name>WaypointItem</name>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="26"/>
        <source>Name</source>
        <translation>Název</translation>
    </message>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="27"/>
        <source>Coordinates</source>
        <translation>Souřadnice</translation>
    </message>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="34"/>
        <source>Elevation</source>
        <translation>Výška</translation>
    </message>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="38"/>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="43"/>
        <source>Description</source>
        <translation>Popis</translation>
    </message>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="47"/>
        <source>Comment</source>
        <translation>Poznámka</translation>
    </message>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="50"/>
        <source>Symbol</source>
        <translation>Symbol</translation>
    </message>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="55"/>
        <source>Address</source>
        <translation>Adresa</translation>
    </message>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="58"/>
        <source>Phone</source>
        <translation>Telefon</translation>
    </message>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="68"/>
        <source>Links</source>
        <translation>Odkazy</translation>
    </message>
</context>
</TS>
